[![CircleCI](https://circleci.com/gh/khanlab/dicom2tar/tree/master.svg?style=svg)](https://circleci.com/gh/khanlab/dicom2tar/tree/master)
# dicom2tar
Tool for extract compressed files(if any), sort dicom files according to given rule, or tar the sorted, to a destination directory. 

Check dicom2tar.py for example.
